==> clj-edocu-users-0.1.24-20161017.135040-3.jar: com/edocu/users/configuration.clj <==
(ns com.edocu.users.configuration
  (:require [environ.core :as e]))

(def ENV (promise))

(defn env []
  (if-not (realized? ENV)
    (deliver ENV (or
                   (keyword (e/env :env))
                   :dev)))
  @ENV)

(defn ^String USER_PRIVILEGES_IN_ELEMENT [element_hash]
  (format "%s%s"
          (case (env)
            (:prod :prod_unsecure) "http://nugeta.service.prod.edocu.local/user-privileges/in-element/"
            "http://nugeta.service.dev.edocu.local/user-privileges/in-element/")
          element_hash))

(defn ^String USER_ORGANIZATIONS []
  (case (env)
    (:prod :prod_unsecure) "http://api-old.service.prod.edocu.local/users/organizations"
    "http://api-old.service.dev.edocu.local/users/organizations"))

(defn ^String NUGETA_SERVICE []
  (case (env)
    (:prod :prod_unsecure) "http://nugeta.service.prod.edocu.local"
    "http://nugeta.service.dev.edocu.local"))

(defn ^String USER_PRIVILEGES_IN_ORGANIZATION_FOR_ELEMENT_TYPE [organization_uid element_type_uid]
  (format "%s/user-privileges/%s/%s"
          (NUGETA_SERVICE)
          organization_uid
          element_type_uid))

(defn ^String ELEMENT_TYPES_WITH_PRIVILEGES_IN_ORGANIZATION [user_id organization_id privileges]
  (format "%s/user-privileges/%s/%s/element-types?privs=%s"
          (NUGETA_SERVICE)
          organization_id
          user_id
          privileges))

(defn ^String CREATE_USER []
  (case (env)
    (:prod :prod_unsecure) "http://users.service.prod.edocu.local"
    "http://users.service.dev.edocu.local"))

(def ^:const ^String USER_CREATE_CONTENT_TYPE "application/vnd.edocu.user.v0.0.1+json")

(def ^:const ^Integer RESPONSE_TIME 10000)

(defn ^String CHECK_USER_IN_SECURITY_GROUP
  ([^String user_id ^String security_group_id]
   (format "%s/security-groups/%s/users/%s"
           (NUGETA_SERVICE)
           security_group_id
           user_id))
  ([^String user_id ^String organization_id ^String title]
   (format "%s/security-groups/%s/%s/users/%s"
           (NUGETA_SERVICE)
           organization_id
           title
           user_id)))

==> clj-edocu-users-0.1.25-20170427.122057-1.jar: com/edocu/users/configuration.clj <==
(ns com.edocu.users.configuration
  (:require [environ.core :as e]))

(def ENV (promise))

(defn env []
  (if-not (realized? ENV)
    (deliver ENV (or
                   (keyword (e/env :env))
                   :dev)))
  @ENV)

(defn ^String USER_PRIVILEGES_IN_ELEMENT [element_hash]
  (format "%s%s"
          (case (env)
            (:prod :prod_unsecure) "http://nugeta.service.prod.edocu.local/user-privileges/in-element/"
            :k8s-prod "http://nugeta/user-privileges/in-element/"
            "http://nugeta.service.dev.edocu.local/user-privileges/in-element/")
          element_hash))

(defn ^String USER_ORGANIZATIONS []
  (case (env)
    (:prod :prod_unsecure) "http://api-old.service.prod.edocu.local/users/organizations"
    :k8s-prod "http://api-old/users/organizations"
    "http://api-old.service.dev.edocu.local/users/organizations"))

(defn ^String NUGETA_SERVICE []
  (case (env)
    (:prod :prod_unsecure) "http://nugeta.service.prod.edocu.local"
    :k8s-prod "http://nugeta"
    "http://nugeta.service.dev.edocu.local"))

(defn ^String USER_PRIVILEGES_IN_ORGANIZATION_FOR_ELEMENT_TYPE [organization_uid element_type_uid]
  (format "%s/user-privileges/%s/%s"
          (NUGETA_SERVICE)
          organization_uid
          element_type_uid))

(defn ^String ELEMENT_TYPES_WITH_PRIVILEGES_IN_ORGANIZATION [user_id organization_id privileges]
  (format "%s/user-privileges/%s/%s/element-types?privs=%s"
          (NUGETA_SERVICE)
          organization_id
          user_id
          privileges))

(defn ^String CREATE_USER []
  (case (env)
    (:prod :prod_unsecure) "http://users.service.prod.edocu.local"
    :k8s-prod "http://users"
    "http://users.service.dev.edocu.local"))

(def ^:const ^String USER_CREATE_CONTENT_TYPE "application/vnd.edocu.user.v0.0.1+json")

(def ^:const ^Integer RESPONSE_TIME 10000)

(defn ^String CHECK_USER_IN_SECURITY_GROUP
  ([^String user_id ^String security_group_id]
   (format "%s/security-groups/%s/users/%s"
           (NUGETA_SERVICE)
           security_group_id
           user_id))
  ([^String user_id ^String organization_id ^String title]
   (format "%s/security-groups/%s/%s/users/%s"
           (NUGETA_SERVICE)
           organization_id
           title
           user_id)))
